@@ -2,7 +2,8 @@ from collectd_rest import models
 from rest_framework import serializers
 
 class GraphSerializer(serializers.ModelSerializer):
-	url = serializers.HyperlinkedIdentityField(view_name='graph-detail', lookup_field='name')
+	group = serializers.SlugRelatedField(slug_field='name', queryset=models.GraphGroup.objects.all(), required=True)
+	url = serializers.HyperlinkedIdentityField(view_name='graph-detail', read_only=True)
 
 	class Meta:
 		model = models.Graph
@@ -14,7 +15,7 @@ class GraphSerializer(serializers.ModelSerializer):
 		return attrs
 
 class GraphGroupSerializer(serializers.ModelSerializer):
-	graphs = GraphSerializer(many=True)
+	graphs = GraphSerializer(many=True, read_only=True)
 
 	class Meta:
 		model = models.GraphGroup
