@@ -1,3 +1,6 @@
+import os
+BASE_DIR = os.path.dirname(os.path.dirname(__file__))
+
 SECRET_KEY = 'fake-key'
 INSTALLED_APPS = [
 	'rest_framework',
